==> ubuntu_localizations-0.3.2.tar.gz: lib/src/l10n/ubuntu_localizations_tr.dart <==
import 'ubuntu_localizations.dart';

/// The translations for Turkish (`tr`).
class UbuntuLocalizationsTr extends UbuntuLocalizations {
  UbuntuLocalizationsTr([String locale = 'tr']) : super(locale);

  @override
  String get countryCode => 'TR';

  @override
  String get languageName => 'Türkçe';

  @override
  String get backAction => 'Geri Git';

  @override
  String get continueAction => 'Devam et';

  @override
  String get strongPassword => 'Güçlü parola';

  @override
  String get fairPassword => 'Makul parola';

  @override
  String get goodPassword => 'İyi parola';

  @override
  String get weakPassword => 'Zayıf parola';

  @override
  String get altKey => 'Alt';

  @override
  String get controlKey => 'Control';

  @override
  String get metaKey => 'Üst';

  @override
  String get shiftKey => 'Shift';

  @override
  String get aboutLabel => 'Hakkında';

  @override
  String get addLabel => 'Ekle';

  @override
  String get allLabel => 'Tümü';

  @override
  String get applyLabel => 'Uygula';

  @override
  String get ascendingLabel => 'Artan';

  @override
  String get backLabel => 'Geri';

  @override
  String get boldLabel => 'Kalın';

  @override
  String get bottomLabel => 'Alt';

  @override
  String get cancelLabel => 'İptal et';

  @override
  String get centerLabel => 'Ortala';

  @override
  String get clearLabel => 'Temizle';

  @override
  String get closeLabel => 'Kapat';

  @override
  String get colorLabel => 'Renk';

  @override
  String get connectLabel => 'Bağlan';

  @override
  String get continueLabel => 'Devam Et';

  @override
  String get copyLabel => 'Kopyala';

  @override
  String get createLabel => 'Oluştur';

  @override
  String get cutLabel => 'Kes';

  @override
  String get decreaseLabel => 'Azalt';

  @override
  String get deleteLabel => 'Sil';

  @override
  String get descendingLabel => 'Azalan';

  @override
  String get discardLabel => 'Gözden çıkar';

  @override
  String get disconnectLabel => 'Bağlantıyı kes';

  @override
  String get doneLabel => 'Bitti';

  @override
  String get downloadLabel => 'İndir';

  @override
  String get editLabel => 'Düzenle';

  @override
  String get enterLabel => 'Enter';

  @override
  String get errorLabel => 'Hata';

  @override
  String get executeLabel => 'Yürüt';

  @override
  String get exitLabel => 'Çıkış';

  @override
  String get fileLabel => 'Dosya';

  @override
  String get fillLabel => 'Doldur';

  @override
  String get findLabel => 'Bul';

  @override
  String get firstLabel => 'İlk';

  @override
  String get fontLabel => 'Yazı Tipi';

  @override
  String get forwardLabel => 'İleri';

  @override
  String get fullscreenLabel => 'Tam Ekran';

  @override
  String get goBackLabel => 'Geri Git';

  @override
  String get helpLabel => 'Yardım';

  @override
  String get homeLabel => 'Başlangıç';

  @override
  String get importLabel => 'İçe Aktar';

  @override
  String get increaseLabel => 'Artır';

  @override
  String get indexLabel => 'İndis';

  @override
  String get informationLabel => 'Bilgi';

  @override
  String get insertLabel => 'Ekle';

  @override
  String get italicLabel => 'Eğik';

  @override
  String get landscapeLabel => 'Yatay';

  @override
  String get lastLabel => 'Son';

  @override
  String get leaveLabel => 'Ayrıl';

  @override
  String get leftLabel => 'Sol';

  @override
  String get mediaLabel => 'Ortam';

  @override
  String get networkLabel => 'Ağ';

  @override
  String get newLabel => 'Yeni';

  @override
  String get nextLabel => 'Sonraki';

  @override
  String get noLabel => 'Hayır';

  @override
  String get noneLabel => 'Hiçbiri';

  @override
  String get normalLabel => 'Normal';

  @override
  String get okLabel => 'Tamam';

  @override
  String get openLabel => 'Aç';

  @override
  String get pasteLabel => 'Yapıştır';

  @override
  String get pauseLabel => 'Beklet';

  @override
  String get playLabel => 'Oynat';

  @override
  String get portraitLabel => 'Dikey';

  @override
  String get preferencesLabel => 'Tercihler';

  @override
  String get previousLabel => 'Önceki';

  @override
  String get printLabel => 'Yazdır';

  @override
  String get printPreviewLabel => 'Baskı Önizleme';

  @override
  String get propertiesLabel => 'Özellikler';

  @override
  String get questionLabel => 'Soru';

  @override
  String get quitLabel => 'Çık';

  @override
  String get recordLabel => 'Kaydet';

  @override
  String get redoLabel => 'Yinele';

  @override
  String get refreshLabel => 'Yenile';

  @override
  String get removeLabel => 'Kaldır';

  @override
  String get renameLabel => 'Yeniden Adlandır';

  @override
  String get resetLabel => 'Sıfırla';

  @override
  String get restoreLabel => 'Geri Yükle';

  @override
  String get retryLabel => 'Yeniden Yene';

  @override
  String get revertLabel => 'Geri Al';

  @override
  String get rewindLabel => 'Geri Sar';

  @override
  String get rightLabel => 'Sağ';

  @override
  String get saveAsLabel => 'Farklı Kaydet';

  @override
  String get saveLabel => 'Kaydet';

  @override
  String get searchLabel => 'Ara';

  @override
  String get selectAllLabel => 'Tümünü Seç';

  @override
  String get selectLabel => 'Seç';

  @override
  String get sendLabel => 'Gönder';

  @override
  String get skipLabel => 'Atla';

  @override
  String get sortLabel => 'Sırala';

  @override
  String get stopLabel => 'Durdur';

  @override
  String get strikeThroughLabel => 'Üstü Çizili';

  @override
  String get submitLabel => 'Gönder';

  @override
  String get topLabel => 'Üst';

  @override
  String get undoLabel => 'Geri Al';

  @override
  String get updateLabel => 'Güncelle';

  @override
  String get upLabel => 'Yukarı';

  @override
  String get viewLabel => 'Görünüm';

  @override
  String get warningLabel => 'Uyarı';

  @override
  String get windowLabel => 'Pencere';

  @override
  String get yesLabel => 'Evet';

  @override
  String get zoomInLabel => 'Yakınlaştır';

  @override
  String get zoomOutLabel => 'Uzaklaştır';

  @override
  String get byte => 'B';

  @override
  String get kilobyte => 'kB';

  @override
  String get megabyte => 'MB';

  @override
  String get gigabyte => 'GB';

  @override
  String get terabyte => 'TB';

  @override
  String get petabyte => 'PB';
}

==> ubuntu_localizations-0.3.4.tar.gz: lib/src/l10n/ubuntu_localizations_tr.dart <==
import 'ubuntu_localizations.dart';

/// The translations for Turkish (`tr`).
class UbuntuLocalizationsTr extends UbuntuLocalizations {
  UbuntuLocalizationsTr([String locale = 'tr']) : super(locale);

  @override
  String get countryCode => 'TR';

  @override
  String get languageName => 'Türkçe';

  @override
  String get backAction => 'Geri Git';

  @override
  String get continueAction => 'Devam et';

  @override
  String get strongPassword => 'Güçlü parola';

  @override
  String get fairPassword => 'Makul parola';

  @override
  String get goodPassword => 'İyi parola';

  @override
  String get weakPassword => 'Zayıf parola';

  @override
  String get altKey => 'Alt';

  @override
  String get controlKey => 'Control';

  @override
  String get metaKey => 'Üst';

  @override
  String get shiftKey => 'Shift';

  @override
  String get aboutLabel => 'Hakkında';

  @override
  String get addLabel => 'Ekle';

  @override
  String get allLabel => 'Tümü';

  @override
  String get applyLabel => 'Uygula';

  @override
  String get ascendingLabel => 'Artan';

  @override
  String get backLabel => 'Geri';

  @override
  String get boldLabel => 'Kalın';

  @override
  String get bottomLabel => 'Alt';

  @override
  String get cancelLabel => 'İptal et';

  @override
  String get centerLabel => 'Ortala';

  @override
  String get clearLabel => 'Temizle';

  @override
  String get closeLabel => 'Kapat';

  @override
  String get colorLabel => 'Renk';

  @override
  String get connectLabel => 'Bağlan';

  @override
  String get continueLabel => 'Devam Et';

  @override
  String get copyLabel => 'Kopyala';

  @override
  String get createLabel => 'Oluştur';

  @override
  String get cutLabel => 'Kes';

  @override
  String get decreaseLabel => 'Azalt';

  @override
  String get deleteLabel => 'Sil';

  @override
  String get descendingLabel => 'Azalan';

  @override
  String get discardLabel => 'Gözden çıkar';

  @override
  String get disconnectLabel => 'Bağlantıyı kes';

  @override
  String get doneLabel => 'Bitti';

  @override
  String get downloadLabel => 'İndir';

  @override
  String get editLabel => 'Düzenle';

  @override
  String get enterLabel => 'Enter';

  @override
  String get errorLabel => 'Hata';

  @override
  String get executeLabel => 'Yürüt';

  @override
  String get exitLabel => 'Çıkış';

  @override
  String get fileLabel => 'Dosya';

  @override
  String get fillLabel => 'Doldur';

  @override
  String get findLabel => 'Bul';

  @override
  String get firstLabel => 'İlk';

  @override
  String get fontLabel => 'Yazı Tipi';

  @override
  String get forwardLabel => 'İleri';

  @override
  String get fullscreenLabel => 'Tam Ekran';

  @override
  String get goBackLabel => 'Geri Git';

  @override
  String get helpLabel => 'Yardım';

  @override
  String get homeLabel => 'Başlangıç';

  @override
  String get importLabel => 'İçe Aktar';

  @override
  String get increaseLabel => 'Artır';

  @override
  String get indexLabel => 'İndis';

  @override
  String get informationLabel => 'Bilgi';

  @override
  String get insertLabel => 'Ekle';

  @override
  String get italicLabel => 'Eğik';

  @override
  String get landscapeLabel => 'Yatay';

  @override
  String get lastLabel => 'Son';

  @override
  String get leaveLabel => 'Ayrıl';

  @override
  String get leftLabel => 'Sol';

  @override
  String get mediaLabel => 'Ortam';

  @override
  String get networkLabel => 'Ağ';

  @override
  String get newLabel => 'Yeni';

  @override
  String get nextLabel => 'Sonraki';

  @override
  String get noLabel => 'Hayır';

  @override
  String get noneLabel => 'Hiçbiri';

  @override
  String get normalLabel => 'Normal';

  @override
  String get okLabel => 'Tamam';

  @override
  String get openLabel => 'Aç';

  @override
  String get pasteLabel => 'Yapıştır';

  @override
  String get pauseLabel => 'Beklet';

  @override
  String get playLabel => 'Oynat';

  @override
  String get portraitLabel => 'Dikey';

  @override
  String get preferencesLabel => 'Tercihler';

  @override
  String get previousLabel => 'Önceki';

  @override
  String get printLabel => 'Yazdır';

  @override
  String get printPreviewLabel => 'Baskı Önizleme';

  @override
  String get propertiesLabel => 'Özellikler';

  @override
  String get questionLabel => 'Soru';

  @override
  String get quitLabel => 'Çık';

  @override
  String get recordLabel => 'Kaydet';

  @override
  String get redoLabel => 'Yinele';

  @override
  String get refreshLabel => 'Yenile';

  @override
  String get removeLabel => 'Kaldır';

  @override
  String get renameLabel => 'Yeniden Adlandır';

  @override
  String get resetLabel => 'Sıfırla';

  @override
  String get restartLabel => 'Yeniden başlat';

  @override
  String get restoreLabel => 'Geri Yükle';

  @override
  String get retryLabel => 'Yeniden Yene';

  @override
  String get revertLabel => 'Geri al';

  @override
  String get rewindLabel => 'Geri Sar';

  @override
  String get rightLabel => 'Sağ';

  @override
  String get saveAsLabel => 'Farklı Kaydet';

  @override
  String get saveLabel => 'Kaydet';

  @override
  String get searchLabel => 'Ara';

  @override
  String get selectAllLabel => 'Tümünü Seç';

  @override
  String get selectLabel => 'Seç';

  @override
  String get sendLabel => 'Gönder';

  @override
  String get skipLabel => 'Atla';

  @override
  String get sortLabel => 'Sırala';

  @override
  String get stopLabel => 'Durdur';

  @override
  String get strikeThroughLabel => 'Üstü Çizili';

  @override
  String get submitLabel => 'Gönder';

  @override
  String get topLabel => 'Üst';

  @override
  String get undoLabel => 'Geri Al';

  @override
  String get updateLabel => 'Güncelle';

  @override
  String get upLabel => 'Yukarı';

  @override
  String get viewLabel => 'Görünüm';

  @override
  String get warningLabel => 'Uyarı';

  @override
  String get windowLabel => 'Pencere';

  @override
  String get yesLabel => 'Evet';

  @override
  String get zoomInLabel => 'Yakınlaştır';

  @override
  String get zoomOutLabel => 'Uzaklaştır';

  @override
  String get byte => 'B';

  @override
  String get kilobyte => 'kB';

  @override
  String get megabyte => 'MB';

  @override
  String get gigabyte => 'GB';

  @override
  String get terabyte => 'TB';

  @override
  String get petabyte => 'PB';
}
